#
# spec file for package kronometer
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kronometer
Version:        2.2.3
Release:        3.5
Summary:        A stopwatch application by KDE
License:        GPL-2.0-or-later
Group:          Productivity/Other
URL:            https://apps.kde.org/kronometer
Source:         https://download.kde.org/stable/kronometer/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core) >= 5.9.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)

%description
Kronometer is a stopwatch application.

Kronometer's main features are the following:

* Start/pause/resume the stopwatch widget
* Laps recording: you can capture the stopwatch time when you want and add a note to it
* Lap times sorting: you can easily find the shortest lap time or the longest one
* Reset the stopwatch widget and the lap times
* Time format settings: you can choose the stopwatch granularity
* Times saving and resuming: you can save the stopwatch status and resume it later
* Font customization: you can choose the fonts for each of the stopwatch digits
* Color customization: you can choose the color for the stopwatch digits and the stopwatch background
* Lap times export: you can export the lap times on a file using the JSON or CSV format

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %find_lang %{name} --with-kde --with-man
  %{kf5_find_htmldocs}

%files -f %{name}.lang
%license COPYING
%doc README
%doc %lang(en) %{_kf5_htmldir}/en/%{name}
%doc %lang(en) %{_kf5_mandir}/man1/%{name}.1.gz
# kf5-filesystem doesn't own this directory in 15.2
%dir %{_kf5_configkcfgdir}
%{_kf5_applicationsdir}/org.kde.kronometer.desktop
%{_kf5_appstreamdir}/org.kde.kronometer.appdata.xml
%{_kf5_bindir}/%{name}
%{_kf5_configkcfgdir}/%{name}.kcfg
%{_kf5_iconsdir}/hicolor/*/apps/kronometer.*

%changelog
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Apr 20 2021 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
- Stop owning directories provided by the filesystem package (boo#1184786)
* Sat Apr 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
* Sun Jul 28 2019 wbauer@tmo.at
- Update to 2.2.3:
  * Fixed bug #349861 (thanks to Gaurav Shah):
    https://bugs.kde.org/show_bug.cgi?id=349861 (kde#349861)
  * Updated translations
* Tue May 21 2019 wbauer@tmo.at
- Update to 2.2.2:
  * Updated translations
- Update URL, www.aelog.org doesn't exist anymore
- Run spec-cleaner
* Sat Jan 27 2018 wbauer@tmo.at
- Update to 2.2.1:
  * Fixed laps sorting
  * Updated translations
* Fri Dec  8 2017 wbauer@tmo.at
- Update to 2.2.0:
  * Fixed laps export feature (Qt >= 5.9 is now required)
  * Implemented screen inhibition while a stopwatch is running
* Sat Jun 17 2017 wbauer@tmo.at
- Update to 2.1.5:
- v2.1.5
  * Fixed width of columns in the laps view.
  * Updated translations.
- v2.1.4
  * Updated homepage links
- v2.1.3
  * Fix build with ECM >= 5.31
  * Prevent warning messagebox with kxmlgui >= 5.30
- v2.1.2
  * Fix default size of Session dialog.
  * Don't assume there are always sessions saved.
  * Updated translations.
- v2.1.1
  * Window size can now be restored (kde#361494)
  * Fix wrongly-enabled Save action (kde#352993)
  * Fix appereance of Lap View (kde#365101)
- v2.1.0
  * Improved usability of dialogs.
  * Moved toolbar to top position.
  * Menubar is now hidden by default.
  * Dropped statusbar.
- v2.0.2
  * Fixed invisible main window with Qt 5.6
- v2.0.1
  * Fixed default height of the Kronometer window (kde#351746)
- v2.0.0
  * Port to Qt5 and KDE Frameworks 5
  * New Breeze icons: app icon and start/pause/reset/lap icons
  * Sessions persistence through a simple Session dialog, instead
    of XML files
  * Improved the Settings dialog and removed useless settings
  * Hours are now hidden by default, both in stopwatch time and
    laps times.
  * Laps absolute times are now hidden by default
  * Laps notes can now be hidden
  * Suspension awareness: pause running stopwatch if the OS is
    going to sleep (kde#349824)
  * Cleaned up UI and visible string messages
  * Stopwatch time format is automatically ovverridden when
    needed (kde#343130)
  * Fixed BUG 344714 (kde#344714)
  * Laps can now be exported to the JSON format, but not anymore
    to XML
  * Fixed Kronometer handbook not being shown from Help ->
    Kronometer Handbook
  * Added manpage
  * Development: added autotests
- Adjust package description
* Sat Feb 28 2015 mailaender@opensuse.org
- initial packaging of version 1.6.0
